#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.3.0
visibility:           public
id:                   named-text-1.2.3.0-InsfWeB3w8KKf0q0qmZ6ch
key:                  named-text-1.2.3.0-InsfWeB3w8KKf0q0qmZ6ch
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  cd577cb433f56eec2351f759d455c296
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/named-text-1.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/named-text-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/named-text-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.3.0-InsfWeB3w8KKf0q0qmZ6ch
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87
    sayable-1.2.7.0-3b2V8RTFIHdHyF6ZzE2fCm text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

